/*****************************************************************
******************************************************************
** Project for the K8055 USB I/O Card  JAVA-WRAPPER             **
**                                                              **
**                    Copyright Mike Peter                      **
**                                                              **
**                                                              **
**                                                              **
**                                                              **
**                        Developed by                          **
**                         Mike Peter                           **
**                      mike.peter@gmx.de                       **
******************************************************************
******************************************************************/
#include <stdio.h> 
#include <windows.h>
#include <jni.h>
#include <usb_interface.h>
#include <K8055D_C.h>

// Beep zum TEST 
typedef void (CALLBACK* BeepType)(int in_int1, int in_int2);

JNIEXPORT void JNICALL Java_usb_1interface_JBeep
  (JNIEnv *env,jclass in_cls, jint in_int1, jint in_int2)
{ 
	    HINSTANCE dllHandle;
        BeepType BeepPtr ;
   	    BOOL freeResult = FALSE;
        
         
	// Hole Handle fuer die DLL. 
	dllHandle = LoadLibrary("Kernel32.dll"); 
	// Wenn Handle gueltig, ermittle Adresse der Funktion die wirklich Aufgerufen werden soll ! 
	if (dllHandle != NULL) { 
		BeepPtr = (BeepType) GetProcAddress(dllHandle, "Beep"); 
		// Wenn Adresse gueltig, rufe die Funktion auf. 
		if (NULL != BeepPtr) {
			BeepPtr(in_int1, in_int2); 
		} 
        else {
             printf("Not Function in DLL !!!\n");
        }     

	// Aufraeumen 
	freeResult = FreeLibrary(dllHandle); 
	} 
	return ; 
}  

// OpenDevice
JNIEXPORT jlong JNICALL Java_usb_1interface_JOpenDevice
          (JNIEnv *env, jclass in_cls, jlong CardAddress)
{ 
   long retCode = -1 ;
   
   // Kontrolle bei Fehlersuche  
   //printf("C-Open Device : %d\n",CardAddress);
   retCode = OpenDevice(CardAddress); 
   return retCode; 
} 
  
// CloseDevice
JNIEXPORT void JNICALL Java_usb_1interface_JCloseDevice
          (JNIEnv *env, jclass in_cls)
{ 
	CloseDevice(); 
	return ; 
}

// ReadAnalogChannel 
JNIEXPORT jlong JNICALL Java_usb_1interface_JReadAnalogChannel
  (JNIEnv *env, jclass in_cls, jlong in_channel)
{ 
   long retCode = -1 ;
   
   // Kontrolle bei Fehlersuche  
   //printf("C-Analog Channel : %d\n",in_channel);
   retCode = ReadAnalogChannel(in_channel); 
   return retCode; 
} 

// ReadAllAnalog
JNIEXPORT jlongArray JNICALL Java_usb_1interface_JReadAllAnalog
  (JNIEnv *env, jclass in_cls ) 
  
{
    long retData1 = -1 ; // Typ Long
    long retData2 = -1 ; // Typ Long
    long * pretData1; // Typ Long
    long * pretData2; // Typ Long

    pretData1 = &retData1;
    pretData2 = &retData2;

    /* Neues jlongArray der Klasse "Response" erzeuegen und initialisieren: */
    jlongArray alRet=env->NewLongArray(2);
    jlong *retBody = env->GetLongArrayElements(alRet, 0) ;
  
   // Kontrolle bei Fehlersuche  
   //printf("C-ALL Analog Channel : %d\n");

   // Programmaufruf mit Pointer-bergabe
   ReadAllAnalog(pretData1, pretData2);

   // Rein ins Response Array
   jlong jretData1 = retData1;
   jlong jretData2 = retData2;
   retBody[0] = jretData1;
   retBody[1] = jretData2;

   // Kontrolle bei Fehlersuche  
   //printf("C-ALL Analog : %d\n", retBody[0]);
   //printf("C-ALL Analog : %d\n", retBody[1]);

   // Rckkopieren der Daten in das Response Array
   env->ReleaseLongArrayElements(alRet, retBody, 0); 
  
    //Bei Bedarf Speicher der Zeiger freigeben freigeben und rckkopieren
   free (pretData1);
   free (pretData2);
   
   return alRet; 
} 

// OutputAnalogChannel
JNIEXPORT void JNICALL Java_usb_1interface_JOutputAnalogChannel
  (JNIEnv *env, jclass in_cls, jlong channel, jlong data)
{ 
   // Kontrolle bei Fehlersuche  
   //printf("C-Output Analog : %d - %d \n", channel ,data );
   OutputAnalogChannel(channel, data); 
   return ; 
} 

// OutputAllAnalog
JNIEXPORT void JNICALL Java_usb_1interface_JOutputAllAnalog
  (JNIEnv *env, jclass in_cls, jlong data1, jlong data2)
{ 
   // Kontrolle bei Fehlersuche  
   //printf("C-Output Analog : %d - %d \n", data1 ,data2 );
   OutputAllAnalog(data1, data2); 
   return ; 
} 

// ClearAnalogChannel
JNIEXPORT void JNICALL Java_usb_1interface_JClearAnalogChannel
  (JNIEnv *env, jclass in_cls, jlong channel)
{ 
   // Kontrolle bei Fehlersuche  
   //printf("C-Clear Analog : %d\n", channel);
   ClearAnalogChannel(channel); 
   return ; 
} 

// ClearAllAnalog
JNIEXPORT void JNICALL Java_usb_1interface_JClearAllAnalog
  (JNIEnv *env, jclass in_cls)
{ 
   // Kontrolle bei Fehlersuche  
   //printf("C-Clear ALL Analog \n");
   ClearAllAnalog(); 
   return ; 
} 

// SetAnalogChannel
JNIEXPORT void JNICALL Java_usb_1interface_JSetAnalogChannel
  (JNIEnv *env, jclass in_cls, jlong channel)
{ 
   // Kontrolle bei Fehlersuche  
   //printf("C-Set Analog : %d\n", channel);
   SetAnalogChannel(channel); 
   return ; 
} 

// SetAllAnalog
JNIEXPORT void JNICALL Java_usb_1interface_JSetAllAnalog
  (JNIEnv *env, jclass in_cls)
{ 
   // Kontrolle bei Fehlersuche  
   //printf("C-Set ALL Analog \n");
   SetAllAnalog(); 
   return ; 
} 

// WriteAllDigital
JNIEXPORT void JNICALL Java_usb_1interface_JWriteAllDigital
  (JNIEnv *env, jclass in_cls, jlong data)
{ 
   // Kontrolle bei Fehlersuche  
   //printf("C-WriteAllDigigal : %d\n", data);
   WriteAllDigital(data); 
   return ; 
} 

// ClearDigitalChannel
JNIEXPORT void JNICALL Java_usb_1interface_JClearDigitalChannel
  (JNIEnv *env, jclass in_cls, jlong channel)
{ 
   // Kontrolle bei Fehlersuche  
   //printf("C-ClearDigigalChannel : %d\n", channel);
   ClearDigitalChannel(channel); 
   return ; 
} 

// ReadDigitalChannel
JNIEXPORT jboolean JNICALL Java_usb_1interface_JReadDigitalChannel
  (JNIEnv *env, jclass in_cls, jlong channel)
{ 
   jboolean retCode = false ;
   
   // Kontrolle bei Fehlersuche  
   //printf("C-ReadDigitalChannel : %d\n", channel);
   retCode = ReadDigitalChannel(channel); 
   return retCode; 
} 

// ReadAllDigital
JNIEXPORT jlong JNICALL Java_usb_1interface_JReadAllDigital
  (JNIEnv *env, jclass in_cls)
{ 
   long retCode = -1 ;
   
   retCode = ReadAllDigital(); 
   // Kontrolle bei Fehlersuche  
   //printf("C-ReadDigitalChannel : %d\n", retCode);

   return retCode; 
} 

// ClearAllDigital
JNIEXPORT void JNICALL Java_usb_1interface_JClearAllDigital
  (JNIEnv *env, jclass in_cls)
{ 
    // Kontrolle bei Fehlersuche  
    //printf("C-Clearen ALLER Digital-Channel \n");
	ClearAllDigital(); 
	return ; 
}

// SetDigitalChannel
JNIEXPORT void JNICALL Java_usb_1interface_JSetDigitalChannel
  (JNIEnv *env, jclass in_cls, jlong in_channel)
{
    // Kontrolle bei Fehlersuche  
    //printf("C-Setzen Digital-Channel : %d\n",in_channel);
    SetDigitalChannel(in_channel); 
    return ; 
}   

// SetAllDigital
JNIEXPORT void JNICALL Java_usb_1interface_JSetAllDigital
  (JNIEnv *env, jclass in_cls)
{
    // Kontrolle bei Fehlersuche  
    //printf("C-Setzen ALLER Digital-Channel \n");
	SetAllDigital(); 
	return ; 
}

// ResetCounter
JNIEXPORT void JNICALL Java_usb_1interface_JResetCounter
  (JNIEnv *env, jclass in_cls, jlong counter)
{
    // Kontrolle bei Fehlersuche  
    //printf("C-Reset Counter : %d\n",counter);
    ResetCounter(counter); 
    return ; 
}   

// SetCounterDebounceTime
JNIEXPORT void JNICALL Java_usb_1interface_JSetCounterDebounceTime
  (JNIEnv *env, jclass in_cls, jlong counter, jlong deb_time)
{
    // Kontrolle bei Fehlersuche  
    //printf("C-Set Counter Debounce time: %d >>> %d\n",counter, deb_time);
    SetCounterDebounceTime(counter,deb_time); 
    return ; 
} 

// ReadCounter
JNIEXPORT jlong JNICALL Java_usb_1interface_JReadCounter
  (JNIEnv *env, jclass in_cls, jlong counter)
{ 
   long retCode = -1 ;
   
   retCode = ReadCounter(counter); 
   // Kontrolle bei Fehlersuche  
   //printf("C-ReadCounter : %d\n", retCode);

   return retCode; 
}

// Version
JNIEXPORT void JNICALL Java_usb_1interface_JVersion
  (JNIEnv *env, jclass in_cls) 
{
    // Kontrolle bei Fehlersuche  
    //printf("C-Aufruf-Version\n");
    Version(); 
	return; 
} 

// SearchDevice
JNIEXPORT jlong JNICALL Java_usb_1interface_JSearchDevices
  (JNIEnv *env, jclass im_cls)
{
   long retCode = -1 ;
   
   retCode = SearchDevices(); 
   // Kontrolle bei Fehlersuche  
   //printf("C-SearchDevice : %d\n", retCode);

   return retCode; 
}

// SetCurrentDevice
JNIEXPORT jlong JNICALL Java_usb_1interface_JSetCurrentDevice
  (JNIEnv *, jclass, jlong pvAddress)

{
   long retCode = -1 ;
   
   retCode = SetCurrentDevice(pvAddress); 
   // Kontrolle bei Fehlersuche  
   // printf("C-SetCurrentDevice : %d - %d\n",pvAddress, retCode);

   return retCode; 
}


