/******************************************************************/
/******************************************************************/
/** Project for the K8055 USB I/O Card  JAVA-WRAPPER             **/
/**                                                              **/
/**                    Copyright by Mike Peter                   **/
/**                                                              **/
/**                                                              **/
/**                                                              **/
/**                                                              **/
/**                        Developed by                          **/
/**                         Mike Peter                           **/
/**                      mike.peter@gmx.de                       **/
/******************************************************************/
/******************************************************************/

public class usb_interface {

    // TEST mit BEEP von Windows
    private static native void JBeep(int i1, int i2);

    // ffnen der Verbindung zum K8055	
    private static native long JOpenDevice(long i);
    // Schlieen der Verbindung K8055	
    private static native void JCloseDevice();

    // Lesen Analog Channel - Umwandlung der Eingangsspannung in einem Wert 0-255
    private static native long JReadAnalogChannel(long channel);
    // Lesen ALLER Analog Channel in jeweils einem Array - Umwandlung der Eingangsspannung in einem Wert 0-255
    private static native long [] JReadAllAnalog();

    // Setzen Analogchannel - Umwandlung des Ausgabewertes (0-255) in eine Ausgangsspannung (0-5V)
    private static native void JOutputAnalogChannel(long channel, long data);
    // Setzen ALLER Analogchannel - Umwandlung des Ausgabewertes (0-255) in eine Ausgangsspannung (0-5V)
    private static native void JOutputAllAnalog(long data1, long data2);

    // Setzen des Analogchannel auf MINIMUM = 0V
    private static native void JClearAnalogChannel(long channel);
    // Setzen ALLER Analogchannel auf MINIMUM = 0V
    private static native void JClearAllAnalog();

    // Setzen des Analogchannel auf MAXIMUM = 5V
    private static native void JSetAnalogChannel(long channel);
    // Setzen ALLER Analogchannel auf MAXIMUM = 5V
    private static native void JSetAllAnalog();

    // Setzen der Digitalen Channel Bit-Codiert (1=ON 0=OFF) Wert 0-255 (Bsp 7 : ON-ON-ON-OFF-OFF-OFF-OFF-OFF)
    private static native void JWriteAllDigital(long data);
    // Setzen des ausgewhlten Digital Channel auf 0=OFF
    private static native void JClearDigitalChannel(long channel);
    // Setzen aller Digital Channel auf 0=OFF
    private static native void JClearAllDigital();

    // Setzen des ausgewhlten Digital Channel auf 1=ON
    private static native void JSetDigitalChannel(long channel);
    // Setzen aller Digital Channel auf 1=ON
    private static native void JSetAllDigital();
   
    // Lesen des Status des ausgewhlten Digital Channel ( 1- 4 )
    private static native boolean JReadDigitalChannel(long channel);
    // Lesen des Status aller Digital Channel Bit-Codiert (1=ON 0=OFF) Wert 0-128
    private static native long JReadAllDigital();

    // Lesen des Inhaltes Impulszhlers des Digitalen Eingnge ( 1 oder 2 ) 
    private static native long JReadCounter(long Counternr);
    // Zurcksetzen des Impulszhlers des Digitalen Zhlers ( 1 oder 2 ) 
    private static native void JResetCounter(long Counternr);
    // Setzen der Entprellzeit zwischen den Impulsen des Impulszhlers des Digitalen Zhlers ( 1 oder 2 )
    // Wert in milisekunden 0-5000 
    private static native void JSetCounterDebounceTime(long Counternr, long deb_time);

    // Abfrage der aktuellen Version
    private static native void JVersion();
    // Suche der aktiven K8055 Devices
    private static native long JSearchDevices();
    // Setzen bzw. ndern der aktuellen K8055 Device ( 0 - 3 )	
    private static native long JSetCurrentDevice(long lngCardAddress);

    // DLL laden
    static {
         System.loadLibrary( "J-K8055-wrapper" );
    } 


    // Allgemeine Variablen 
    static int i1 = 1000;		// Beep Frequenz
    static int i2 = 500;		// Beep Lnge

    static int i;			// Allgemeiner Zhler

    static long pvAddress = 0;		// Adresse fr IO-Borad  SP5-6
    static long pvAddress_Result;	// Adresse fr alle weiteren Aktionen



    static long set_channel_a_1 = 1; 	// Analog Kanal 1
    static long set_channel_a_2 = 2; 	// Analog Kanal 2

    static int cmax = 8;		// Anzahl der Digitalen Ausgnge
    static int amax = 12;		// Max Wert fr Ausgang Analog

    static int read_zyk = 5;		// Anzahl der Lesezyklen	

 


    // Hauptprogramm 	
    public static void main(String args[]) throws Exception

    {

   	   // DLL laden
           if(System.getProperty("os.name").startsWith("Windows"))
	        System.out.println("Betriebssystem : " + System.getProperty("os.name") );
           else
		{
	          System.out.println("Die J-K8055-Wrapper.dll setzt das Betriebssystem Windows voraus!");
                  System.exit(0);
                }


	System.out.println("******************************************************************");
	System.out.println("******************************************************************");
	System.out.println("** Project for the K8055 USB I/O Card  JAVA-WRAPPER             **");
	System.out.println("**                                                              **");
	System.out.println("**                    Copyright by Mike Peter                   **");
	System.out.println("**                                                              **");
	System.out.println("**                                                              **");
	System.out.println("**                        Developed by                          **");
	System.out.println("**                         Mike Peter                           **");
	System.out.println("**                      mike.peter@gmx.de                       **");
	System.out.println("******************************************************************");
	System.out.println("******************************************************************");
	System.out.println("");

 
        //################################################################################
	// 
	//  An dieser STelle knnen die einzelnen Funktionen zur DEMO ausgewhlt werden !
	//
	//  Wichtig : Der Aufruf prog_close()  darf nicht gesperrt werden!
	//################################################################################		


	//#############################Start Auswahl #####################################

           System.out.println(">>>>> Start Test");

	   prog_beep();				// Beep
//	   prog_version(); 			// Versionsanzeige
//	   prog_SearchDevices();		// Suche Anzahl der verfgbaren Devices K8055
//	   prog_SetCurrentDevice();		// Setzen der Device K8055
//	   prog_close();			// Close

	   prog_open();				// Open

//	   prog_ReadAnalogChannel();		// ReadAnalogChannel
//	   Thread.sleep(1000);
//	   prog_ReadAllAnalog();		// ReadAllAnalog
//    	   Thread.sleep(1000);

//	   prog_OutputAnalogChannel();		// Setzen eines Analogen Channel	
//    	   Thread.sleep(1000);
//	   prog_ClearAnalogChannel();		// Clearen eines Analogen Channel	
//    	   Thread.sleep(1000);

//	   prog_OutputAllAnalog();		// Setzen aller Analogen Channel gleichzeitig
//    	   Thread.sleep(1000);
//	   prog_ClearAllAnalog();		// Clearen Aller Analogen Channel	
//    	   Thread.sleep(1000);

//	   prog_SetAnalogChannel();		// Setzen Analogen Channel auf 1
//    	   Thread.sleep(1000);
//	   prog_ClearAllAnalog();	
//    	   Thread.sleep(1000);

//	   prog_SetAllAnalog();			// Setzen Aller Analogen Channel auf 1
//    	   Thread.sleep(1000);
//	   prog_ClearAllAnalog();

//	   prog_WriteAllDigital();		// Setzen der Digitalen Channel mit BIT-Code
//    	   Thread.sleep(1000);
//	   prog_ClearDigitalChannel();		// Clearen eines Digital Channel
//    	   Thread.sleep(1000);

	   prog_SetDigitalChannel();		// Setzen der Digitalen Ausgnge
    	   Thread.sleep(1000);
	   prog_ClearAllDigital();		// Clearen Alle Digitalen 
	   Thread.sleep(1000);
	   prog_SetAllDigital();		// Setzen Alle Digitalen 
	   Thread.sleep(1000);
	   prog_ClearAllDigital();		// Clearen Alle Digitalen
    	   Thread.sleep(1000);

//	   prog_ReadDigitalChannel();		// Lesen Status des Digitalen IN-Channels 1-5
//    	   Thread.sleep(1000);
//	   prog_ReadAllDigital();		// Lesen Status aller Digitalen IN-Channels
//    	   Thread.sleep(1000);

//	   prog_ResetCounter();			// Reset Zhler Digital Eingang 1 oder 2
//	   prog_SetCounterDebounceTime();	// Einstellen der Entprellzeit Digitaler Eingang 1 oder 2	

//	   prog_ReadCounter();			// Inhalt des Zhlers Digitaler Eingang 1 oder 2

	   prog_close();			// Close
           System.out.println("Ende");


	//############################ ENDE Auswahl #######################################


// Das ENDE MAIN //
}

//######################################################################//
     static void prog_beep() {

	    System.out.println(">>> TEST BEEP >>>" );
	    // Kanal 1	
            try {
                usb_interface.JBeep(i1, i2);
            }
            catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
            }

	}

//######################################################################//
     static void prog_SetCurrentDevice() {

          System.out.println(">>> Wechseln der aktuellen Device");
          // ffnen

	  long tmppvAddress;	
          for ( tmppvAddress = 0; tmppvAddress < 4; tmppvAddress++ )
           {
            try {
                pvAddress_Result = usb_interface.JSetCurrentDevice(tmppvAddress);
                System.out.println("Gewechselt auf Device : "+ tmppvAddress+ "  Ergebniss : " + pvAddress_Result);
            }
            catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
            }

          // NEXT
	  }

	}

//######################################################################//
     static void prog_open() {

            System.out.println(">>> OpenDevice  : " + pvAddress );
            // ffnen
            try {
                pvAddress_Result = usb_interface.JOpenDevice(pvAddress);
                System.out.println("Ergebnis Open Device : " + pvAddress_Result);
            }
            catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
            }

	}

//######################################################################//
     static void prog_SearchDevices() {

            System.out.println(">>> Anzeige Anzahl aktiver Device");
            // ffnen
            try {
                pvAddress_Result = usb_interface.JSearchDevices();
                System.out.println("Anzahl aktive Device : " + pvAddress_Result);
            }
            catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
            }

	}

//######################################################################//
     static void prog_close() {

            // Schlieen
            System.out.println(">>> CloseDevice");
            try {
                usb_interface.JCloseDevice();
            }
            catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
            }
	}


//######################################################################//
     static void prog_version() {

            System.out.println(">>> Ausgabe der Version");
            try {
                usb_interface.JVersion();
            }
            catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
            }
	}
	


//######################################################################//
     static void prog_ReadAnalogChannel() {

	    long result_channel_a_1 = 0 ;
	    long result_channel_a_2 = 0 ;

            System.out.println(">>> ReadAnalogChannel");
	    // Kanal 1	
            try {
                result_channel_a_1 = usb_interface.JReadAnalogChannel(set_channel_a_1);
                System.out.println("J-Analog Channel 1 RET : " + result_channel_a_1);
            }
            catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
            }


	    // Kanal 2	
            try {
            	result_channel_a_2 = usb_interface.JReadAnalogChannel(set_channel_a_2);
          	System.out.println("J-Analog Channel 2 RET : " + result_channel_a_2);
            }
            catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
            }
	}

//######################################################################//
     static void prog_ReadAllAnalog() {

            System.out.println(">>> ReadAllAnalog");
            try {
                long[] data = usb_interface.JReadAllAnalog();
                System.out.println("J-Analog Channel 1 RET : " + data[0]);
                System.out.println("J-Analog Channel 2 RET : " + data[1]);
            }
            catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
            }
	}


//######################################################################//
     static void prog_OutputAnalogChannel() throws Exception  {


            System.out.println(">>> SetAnalogChannel Stufenweise");

	    // Kanal 1
            for ( i= 1; i <= amax; i++ )
            { 
	     System.out.println("J-Setzen Analog Channel 1 : " + (i*20) );
             try {
                usb_interface.JOutputAnalogChannel(set_channel_a_1 , (i*20));
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }

	     Thread.sleep(1000);
	     		
            } 


	    // Kanal 2
            for ( i= 1; i <= amax; i++ )
            { 
	     System.out.println("J-Setzen Analog Channel 2 : " + (i*20) );
             try {
                usb_interface.JOutputAnalogChannel(set_channel_a_2 , (i*20));
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }

	     Thread.sleep(1000);
	     		
            } 

	}

//######################################################################//
     static void prog_OutputAllAnalog() throws Exception  {

            System.out.println(">>> SetAllAnalog Stufenweise");

            for ( i= 1; i <= amax; i++ )
            { 
	     System.out.println("J-Setzen Analog ALL : " + (i*20) );
             try {
                usb_interface.JOutputAllAnalog( (i*20) , (i*20));
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }

	     Thread.sleep(1000);
	     		
            } 

	} 

//######################################################################//
     static void prog_ClearAnalogChannel() throws Exception  {

            System.out.println(">>> ClearAnalogChannel");

	    System.out.println("J-Clear Analog Channel 1");
             try {
                usb_interface.JClearAnalogChannel(set_channel_a_1);
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }


	     Thread.sleep(1000);
             

	    System.out.println("J-Clear Analog Channel 2");
             try {
                usb_interface.JClearAnalogChannel(set_channel_a_2);
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }

	} 

//######################################################################//
     static void prog_ClearAllAnalog() {

            System.out.println(">>> ClearAllAnalog");

             try {
                usb_interface.JClearAllAnalog();
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }


	} 

//######################################################################//
     static void prog_SetAnalogChannel() throws Exception  {

            System.out.println(">>> SetAnalogChannel");

	    System.out.println("J-Setzen Analog Channel 1");
             try {
                usb_interface.JSetAnalogChannel(set_channel_a_1);
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }


	     Thread.sleep(1000);
             

	    System.out.println("J-Setzen Analog Channel 2");
             try {
                usb_interface.JSetAnalogChannel(set_channel_a_2);
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }

	} 


//######################################################################//
     static void prog_SetAllAnalog()  {

            System.out.println(">>> SetAllAnalog");

             try {
                usb_interface.JSetAllAnalog();
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }


	} 


//######################################################################//
     static void prog_WriteAllDigital() throws Exception  {

            System.out.println(">>> WriteAllDigital Stufenweise");

            for ( i= 1; i <= amax; i++ )
            { 
	     System.out.println("J-Setzen Digital : " + (i*20) );
             try {
                usb_interface.JWriteAllDigital( (i*20) );
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }

	     Thread.sleep(1000);
	     		
            } 

	} 


//######################################################################//
     static void prog_ClearDigitalChannel() throws Exception {

            System.out.println(">>> ClearDigitalChannel");

            for ( i= 1; i <= cmax; i++)
            { 
	     System.out.println("J-Clear Digital Channel : " + i );
             try {
                usb_interface.JClearDigitalChannel(i);
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }

	     Thread.sleep(1000);
	     		
            } 
	}

//######################################################################//
     static void prog_ClearAllDigital() {

            System.out.println(">>>  Alle Digitalen Lschen !");
            try {
                usb_interface.JClearAllDigital();
            }
            catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
            }
	}


//######################################################################//
     static void prog_SetDigitalChannel() throws Exception {

            System.out.println(">>> SetDigitalChannel");

            for ( i= 1; i <= cmax; i++)
            { 
	     System.out.println("J-Setzen Channel : " + i );
             try {
                usb_interface.JSetDigitalChannel(i);
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }

	     Thread.sleep(1000);
	     		
            } 
	}
	

//######################################################################//
     static void prog_SetAllDigital() {

            System.out.println(">>>  Alle Digitalen Setzen !");
            try {
                usb_interface.JSetAllDigital();
            }
            catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
            }
	}



//######################################################################//
     static void prog_ReadDigitalChannel() throws Exception{

            int m = 0;
    	    boolean stat_channel = false; 		// Zustand Kanal 

            System.out.println(">>> ReadDigiatlChannel");
	    // Kanal 1

        for (m=1 ; m <= 5; m++)
         {  
            for ( i= 1; i <= read_zyk; i++)
            { 
             try {
                stat_channel = usb_interface.JReadDigitalChannel(m);
                System.out.println("J-Digital Channel " +m+ " >>> " + stat_channel);
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }

             // Verzgerung fr nchste Zhlung
 	     Thread.sleep(1000);

	    }

         }
    }

//######################################################################//
     static void prog_ReadAllDigital() throws Exception {

       long read_result;
       System.out.println(">>> ReadAllDigital");


            for ( i= 1; i <= read_zyk; i++)
            { 
             try {
                read_result = usb_interface.JReadAllDigital();
                System.out.println("J-Digital All Channel : " + read_result);
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }

             // Verzgerung fr nchste Zhlung
 	     Thread.sleep(1000);

	    }

    }

//######################################################################//
     static void prog_ResetCounter() throws Exception {

	long set_channel_d_1 = 1; 	// Digital Kanal 1
    	long set_channel_d_2 = 2; 	// Digital Kanal 2

       System.out.println(">>> ResetCounter");

	     // 1. Kanal	
             try {
                usb_interface.JResetCounter(set_channel_d_1);
                System.out.println("J-Reset Digital Counter : " + set_channel_d_1);
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }

             // Verzgerung fr nchste Zhlung
 	     Thread.sleep(1000);

	     // 2. Kanal	
             try {
                usb_interface.JResetCounter(set_channel_d_2);
                System.out.println("J-Reset Digital Counter : " + set_channel_d_2);
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }


    }


//######################################################################//
     static void prog_ReadCounter() throws Exception {

       	long read_result;
	long set_channel_d_1 = 1; 	// Digital Kanal 1
    	long set_channel_d_2 = 2; 	// Digital Kanal 2


       System.out.println(">>> ReadCounter");

	    // 1. Kanal	
            for ( i= 1; i <= read_zyk; i++)
            { 
             try {
                read_result = usb_interface.JReadCounter(set_channel_d_1 );
                System.out.println("J-Read Digital Counter "+ set_channel_d_1+ " >>> " + read_result);
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }

             // Verzgerung fr nchste Zhlung
 	     Thread.sleep(1000);

	    }


 	    // 2. Kanal
            for ( i= 1; i <= read_zyk; i++)
            { 
             try {
                read_result = usb_interface.JReadCounter(set_channel_d_2 );
                System.out.println("J-Read Digital Counter "+ set_channel_d_2+ " >>> " + read_result);
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }

             // Verzgerung fr nchste Zhlung
 	     Thread.sleep(1000);

	    }



    }


//######################################################################//
     static void prog_SetCounterDebounceTime() throws Exception {

	long set_channel_d_1 = 1; 	// Digital Kanal 1
    	long set_channel_d_2 = 2; 	// Digital Kanal 2

	int deb_time = 20;		// Debounce Time

       System.out.println(">>> SetCounterDbounceTime");
	     // 1. Kanal	
             try {
                usb_interface.JSetCounterDebounceTime(set_channel_d_1, deb_time );
                System.out.println("J-Set Digital Channel : " + set_channel_d_1 +" >>> " + deb_time +" milisec");
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }

             // Verzgerung fr nchste Zhlung
 	     Thread.sleep(1000);

	     // 2. Kanal	
             try {
                usb_interface.JSetCounterDebounceTime(set_channel_d_2, deb_time );
                System.out.println("J-Set Digital Channel : " + set_channel_d_2 +" >>> " + deb_time +" milisec");
             }
             catch(Exception e) {
                System.out.println("ERROR : ");
                e.printStackTrace();
             }

    }




// Klassen ENDE //
}